<?php
/**
 * @version SOFORT Gateway 3.3.0 - $Date: 2013-01-25 10:10:08 +0100 (Fri, 25 Jan 2013) $
 * @author SOFORT AG (integration@sofort.com)
 * @link http://www.sofort.com/
 *
 * Copyright (c) 2012 SOFORT AG
 *
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 *
 * $Id: sofort_su.php 5966 2013-01-25 09:10:08Z boehm $
 */

require_once(DIR_FS_CATALOG.'ext/modules/payment/sofort/sofort.php');
require_once(DIR_FS_CATALOG.'ext/modules/payment/sofort/library/sofortLib.php');

$language = HelperFunctions::getSofortLanguage($_SESSION['language']);
require_once(DIR_FS_CATALOG.'includes/languages/'.$language.'/modules/payment/sofort_su.php');

class sofort_su extends sofort {
	
	function sofort_su() {
		global $order;
		
		parent::sofort();
		
		$this->_checkExistingSofortConstants('su');
		$this->code = 'sofort_su';
		$this->code_short = 'su';
		$this->paymentMethod = 'SU';
		$this->title = SOFORT_SOFORTUEBERWEISUNG_TEXT_TITLE;
		$this->public_title = SOFORT_SU_TEXT_TITLE;
		
		if (defined('SOFORT_SU_KS_STATUS') && SOFORT_SU_KS_STATUS == 'True') $this->public_title = SOFORT_SU_KS_TEXT_TITLE;
		
		if(defined('SOFORT_SU_RECOMMENDED_PAYMENT') && SOFORT_SU_RECOMMENDED_PAYMENT == 'True') $this->public_title .= ' ' . SOFORT_SU_RECOMMENDED_PAYMENT_TEXT;
		
		$this->enabled = ((defined('SOFORT_SU_STATUS') && SOFORT_SU_STATUS == 'True') ? true : false);
		$this->description = SOFORT_SU_TEXT_DESCRIPTION.'<br />'.SOFORT_MULTIPAY_VERSIONNUMBER.': '.HelperFunctions::getSofortmodulVersion();
		
		if ($this->_isInstalled() && (!defined('SOFORT_MULTIPAY_MODULE_VERSION') || strcasecmp(trim(SOFORT_MULTIPAY_MODULE_VERSION), trim(HelperFunctions::getSofortmodulVersion())) != 0)) {
			$this->description = '<span style ="color:red; font-weight: bold; font-size: 1.2em">'.SOFORT_MULTIPAY_UPDATE_NOTICE.'</span><br /><br />'.$this->description;
		}
		
		$this->description .= SOFORT_SU_TEXT_DESCRIPTION_EXTRA;
		$this->sort_order = (defined('SOFORT_SU_SORT_ORDER') ? SOFORT_SU_SORT_ORDER : false);
		
		if (is_object($order)) $this->update_status();
		
		if (defined('SOFORT_SU_STATUS')) {
			$this->sofort = new SofortLib_Multipay(SOFORT_MULTIPAY_CONFIGURATION_KEY);
			$this->sofort->setVersion(HelperFunctions::getSofortmodulVersion());
			
			if (defined('SOFORT_MULTIPAY_LOG_ENABLED') && SOFORT_MULTIPAY_LOG_ENABLED == "True") $this->sofort->setLogEnabled();
		}
	}
	
	
	function selection() {
		if (!parent::selection()) {
			$this->sofort->log("Notice: Paymentmethod ".$this->code." will be deactivated for selection.");
			$this->enabled = false;
			
			return false;
		}
		
		$title = '';
		
		switch (SOFORT_MULTIPAY_IMAGE) {
			case 'Logo & Text':
				if(SOFORT_SU_KS_STATUS == 'True') {
					$title = $this->_setImageText('logo_155x50.png', SOFORT_MULTIPAY_SU_CHECKOUT_TEXT_KS);
				} else {
					$title = $this->_setImageText('logo_155x50.png', SOFORT_MULTIPAY_SU_CHECKOUT_TEXT);
				}
				break;
			case 'Infographic':
				if(SOFORT_SU_KS_STATUS == 'True') {
					$title = $this->_setImageText('banner_400x100_ks.png', '');
				} else {
					$title = $this->_setImageText('banner_300x100.png', '');
				}
				break;
		}
		
		//add ks-link, if ks is active
		$title = str_replace('[[link_beginn]]', '<a href="'.SOFORT_SU_CHECKOUT_INFOLINK_KS.'" target="_blank">', $title);
		$title = str_replace('[[link_end]]', '</a>', $title);
		
		return array(
			'id' => $this->code,
			'module' => $this->public_title,
			'fields' => array(
					array(
							'title' => $title,
					),
			),
		);
	}
	
	
	function _setImageText($image, $text) {
		$lng = HelperFunctions::getShortCode($_SESSION['language']);
		$image = 'https://images.sofort.com/'.HelperFunctions::getShortCode($_SESSION['language']).'/su/'.$image;
		$image = tep_image($image, SOFORT_SU_TEXT_DESCRIPTION_CHECKOUT_PAYMENT_IMAGEALT);
		$title = SOFORT_SU_TEXT_DESCRIPTION_CHECKOUT_PAYMENT_IMAGE;
		$title = str_replace('{{image}}', $image, $title);
		$title = str_replace('{{text}}', $text, $title);
		
		return $title;
	}
	
	
	function confirmation ($confirmationMessage = '') {
		return parent::confirmation(SOFORT_SU_CHECKOUT_CONFIRMATION);
	}
	
	
	function install() {
		$sofortStatuses = $this->_insertAndReturnSofortStatus();
		$checkStatus = (isset($sofortStatuses['check'])&& !empty($sofortStatuses['check']))? $sofortStatuses['check'] : '';
		$refundedStatus = (isset($sofortStatuses['refunded'])&& !empty($sofortStatuses['refunded']))? $sofortStatuses['refunded'] : '';
		$confirmedStatus = (isset($sofortStatuses['translate_confirmed'])&& !empty($sofortStatuses['translate_confirmed']))? $sofortStatuses['translate_confirmed'] : '';
		$unchangedStatus = (isset($sofortStatuses['unchanged'])&& !empty($sofortStatuses['unchanged']))? $sofortStatuses['unchanged'] : '';
		
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_STATUS_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_STATUS_DESC)."', 'SOFORT_SU_STATUS', 'False', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_KS_STATUS_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_KS_STATUS_DESC)."', 'SOFORT_SU_KS_STATUS', 'False', '6', '30', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SOFORTUEBERWEISUNG_ALLOWED_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SOFORTUEBERWEISUNG_ALLOWED_DESC)."', 'SOFORT_SOFORTUEBERWEISUNG_ALLOWED', '', '6', '12', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_SORT_ORDER_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_SORT_ORDER_DESC)."', 'SOFORT_SU_SORT_ORDER', '0', '6', '16', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_RECOMMENDED_PAYMENT_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_RECOMMENDED_PAYMENT_DESC)."', 'SOFORT_SU_RECOMMENDED_PAYMENT', 'False', '6', '5', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_ZONE_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_ZONE_DESC)."', 'SOFORT_SU_ZONE', '0', '6', '13', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
		//tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_CHECK_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_CHECK_STATUS_ID_DESC)."', 'SOFORT_SU_CHECK_STATUS_ID', '".HelperFunctions::escapeSql($checkStatus)."',  '6', '35', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Best�tigt": pending-not_credited_yet
		//Important notice: constantname is also used for status: untraceable-sofort_bank_account_needed
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_PEN_NOT_CRE_YET_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_PEN_NOT_CRE_YET_STATUS_ID_DESC)."', 'SOFORT_SU_PEN_NOT_CRE_YET_STATUS_ID', '".HelperFunctions::escapeSql($confirmedStatus)."',  '6', '30', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Bestellung pr�fen": loss-not_credited
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_LOS_NOT_CRE_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_LOS_NOT_CRE_STATUS_ID_DESC)."', 'SOFORT_SU_LOS_NOT_CRE_STATUS_ID', '".HelperFunctions::escapeSql($checkStatus)."',  '6', '30', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Geldeingang": received-credited
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_REC_CRE_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_REC_CRE_STATUS_ID_DESC)."', 'SOFORT_SU_REC_CRE_STATUS_ID', '".HelperFunctions::escapeSql($unchangedStatus)."',  '6', '30', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Teilr�ckbuchung": refunded-compensation
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_REF_COM_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_REF_COM_STATUS_ID_DESC)."', 'SOFORT_SU_REF_COM_STATUS_ID', '".HelperFunctions::escapeSql($unchangedStatus)."',  '6', '30', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Vollst�ndige R�ckbuchung": refunded-refunded
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_SU_REF_REF_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_SU_REF_REF_STATUS_ID_DESC)."', 'SOFORT_SU_REF_REF_STATUS_ID', '".HelperFunctions::escapeSql($refundedStatus)."',  '6', '30', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//install shared keys, that are used by all/most multipay-modules
		parent::install();
	}
	
	
	function remove() {
		tep_db_query("DELETE FROM ".TABLE_CONFIGURATION." WHERE configuration_key LIKE 'SOFORT_SU%'");
		tep_db_query("DELETE FROM ".TABLE_CONFIGURATION." WHERE configuration_key LIKE 'SOFORT_SOFORTUEBERWEISUNG%'");
		
		parent::remove();
	}
	
	
	function keys() {
		return array(
			'SOFORT_SU_STATUS' ,
			'SOFORT_MULTIPAY_CONFIGURATION_KEY',
			'SOFORT_MULTIPAY_AUTH',
			'SOFORT_SU_RECOMMENDED_PAYMENT',
			'SOFORT_MULTIPAY_IMAGE' ,
			'SOFORT_MULTIPAY_REASON_1',
			'SOFORT_MULTIPAY_REASON_2' ,
			'SOFORT_SOFORTUEBERWEISUNG_ALLOWED' ,
			'SOFORT_SU_ZONE',
			'SOFORT_SU_SORT_ORDER',
			'SOFORT_MULTIPAY_PROF_SETTINGS',
			'SOFORT_MULTIPAY_TEMP_STATUS_ID',
			'SOFORT_MULTIPAY_ABORTED_STATUS_ID',
			'SOFORT_SU_PEN_NOT_CRE_YET_STATUS_ID',
			'SOFORT_SU_LOS_NOT_CRE_STATUS_ID',
			'SOFORT_SU_REC_CRE_STATUS_ID',
			'SOFORT_SU_REF_COM_STATUS_ID',
			'SOFORT_SU_REF_REF_STATUS_ID',
			//'SOFORT_SU_CHECK_STATUS_ID',
			'SOFORT_SU_KS_STATUS',
			//'SOFORT_MULTIPAY_LOG_ENABLED',
		);
	}
}